@@ -13,7 +13,11 @@ from pdpipe.util import out_of_place_col_insert
 from pdpipe.cq import OfDtypes
 from pdpipe.types import ColumnsParamType, ColumnLabelsType
 
-from pdpipe.shared import _interpret_columns_param, _list_str
+from pdpipe.shared import (
+    _interpret_columns_param,
+    _list_str,
+    _always_true,
+)
 
 from .exceptions import PipelineApplicationError
 
@@ -500,10 +504,6 @@ class MapColVals(ColumnTransformer):
         return series.map(self._applied_value_map)
 
 
-def _always_true(x):
-    return True
-
-
 class ApplyToRows(PdPipelineStage):
     """A pipeline stage generating columns by applying a function to each row.
 
