@@ -106,6 +106,20 @@ class PdpApplicationContext():
         if not self._locked:
             self._dict.__delitem__(key)
 
+    def get(self, key: object, default: object = None) -> object:
+        """Return the value for key if key is in the dictionary, else default
+        If default is not given, it defaults to None, so that this method never
+        raises a KeyError."""
+        return self._dict.get(key, default)
+
+    def items(self):
+        """Return a new view of the context’s items ((key, value) pairs)."""
+        return self._dict.items()
+
+    def keys(self):
+        """Return a new view of the context's keys."""
+        return self._dict.keys()
+
     def pop(self, key: object, default: object) -> object:
         """If key is in the dictionary, remove it and return its value, else
         return default. If default is not given and key is not in the
