@@ -105,6 +105,16 @@ def test_application_context_pickling(pdpipe_tests_dir_path):
     """Testing something."""
     context = PdpApplicationContext()
     context.update({'a': 4})
+    items = list(context.items())
+    assert len(items) == 1
+    assert items[0][0] == 'a'
+    assert items[0][1] == 4
+    keys = list(context.keys())
+    assert len(keys) == 1
+    assert keys[0] == 'a'
+    assert context.get('a') == 4
+    assert context.get('b') is None
+    assert context.get('c', 8) == 8
     fpath = random_pickle_path(pdpipe_tests_dir_path)
     with open(fpath, 'wb+') as f:
         pickle.dump(context, f)
